tonalitytools.QualityIndicator
==============================

.. inheritance-diagram:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator
   :private-bases:

.. autoclass:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.is_uppercase

.. autoattribute:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.quality_string

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__eq__

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__ne__

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__repr__

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__str__

   .. note:: Inherited from `__builtin__.object`
